@@ -90,7 +90,7 @@ class Migration(SchemaMigration):
             'content_fr': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
             'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
             u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'image': ('django.db.models.fields.ImageField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
+            'image': ('django.db.models.ImageField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
             'is_highlighted': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'last_modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
             'position': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
