@@ -11,6 +11,7 @@ from django.test.utils import override_settings
 from django.utils.translation import activate, get_language
 
 from ..models import Page
+from .factories import BarFactory
 from .mixins import TDCMSTestMixin
 
 
@@ -214,6 +215,32 @@ class SetLanguageViewTests(TDCMSTestMixin, TestCase):
                 HTTP_REFERER=self.page.get_absolute_url(),
             )
 
+    def test_redirection_for_a_page_derived_model_detail_view(self):
+        """
+        Test redirection for a Page-derived model detail view
+        """
+        bar = BarFactory(
+            title_en=u'This is a bar',
+            title_fr=u'Ceci est un bar'
+        )
+
+        url = reverse('td_cms_set_language')
+        http_referer = bar.get_absolute_url()
+
+        response = self.client.post(
+            url,
+            {
+                'next': '/',
+                'language': 'fr',
+            },
+            follow=True,
+            HTTP_REFERER=http_referer,
+        )
+
+        expected_path = '/fr/1/ceci-est-un-bar/'
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.request['PATH_INFO'], expected_path)
+
 
 class CategoryDetailViewTests(TDCMSTestMixin, TestCase):
     """
